@@ -9,14 +9,14 @@ from typing import (
     Optional, Tuple, TypeVar, Union, cast
 )
 
-import geojson
 import numpy as np
 import xarray as xr
 from shapely.geometry import Point, Polygon
 from shapely.geometry.base import BaseGeometry
 
-from emsarray import operations, utils
+from emsarray import utils
 from emsarray.compat.shapely import SpatialIndex
+from emsarray.operations import depth
 from emsarray.plot import (
     _requires_plot, animate_on_figure, plot_on_figure,
     polygons_to_patch_collection
@@ -42,7 +42,7 @@ DataArrayOrName = Union[Hashable, xr.DataArray]
 #: This can be an :class:`enum.Enum` listing each different kind of grid.
 #:
 #: :data:`Index` values will be included in the feature properties
-#: of :meth:`Format.make_geojson_geometry`.
+#: of exported geometry from :mod:`emsarray.operations.geometry`.
 #: If the index type includes the grid kind,
 #: the grid kind needs to be JSON serializable.
 #: The easiest way to achieve this is to make your GridKind type subclass :class:`str`:
@@ -240,7 +240,7 @@ class Format(abc.ABC, Generic[GridKind, Index]):
         """Get the name of the time variable in this dataset."""
         for name, variable in self.dataset.variables.items():
             if variable.attrs.get('standard_name') == 'time':
-                return str(name)
+                return name
         raise KeyError("Dataset does not have a time dimension")
 
     def get_depth_name(self) -> Hashable:
@@ -716,7 +716,7 @@ class Format(abc.ABC, Generic[GridKind, Index]):
 
         Parameters
         ----------
-        data_array : str or :class:`xarray.DataArray`, optional
+        data_array : Hashable or :class:`xarray.DataArray`, optional
             A data array, or the name of a data variable in this dataset. Optional.
             If given, the data array is :meth:`linearised <.make_linear>`
             and passed to :meth:`PatchCollection.set_array() <matplotlib.cm.ScalarMappable.set_array>`.
@@ -961,7 +961,7 @@ class Format(abc.ABC, Generic[GridKind, Index]):
         return None
 
     @abc.abstractmethod
-    def selector_for_index(self, index: Index) -> Dict[str, int]:
+    def selector_for_index(self, index: Index) -> Dict[Hashable, int]:
         """
         Convert a format native index into a selector
         that can be passed to :meth:`Dataset.isel <xarray.Dataset.isel>`.
@@ -1054,26 +1054,15 @@ class Format(abc.ABC, Generic[GridKind, Index]):
             raise ValueError("Point did not intersect dataset")
         return self.select_index(index.index)
 
-    def make_geojson_geometry(self) -> geojson.FeatureCollection:
-        """Make a ``geojson.FeatureCollection`` out of the cells in this dataset,
-        one feature per cell.
-
-        Each feature will include the linear index and the native index
-        of the corresponding cell in its properties.
-
-        Returns
-        -------
-        ``geojson.FeatureCollection``
-            The geometry of this dataset
+    @abc.abstractmethod
+    def drop_geometry(self) -> xr.Dataset:
         """
-        return geojson.FeatureCollection([
-            geojson.Feature(geometry=polygon, properties={
-                'linear_index': i,
-                'index': self.unravel_index(i),
-            })
-            for i, polygon in enumerate(self.polygons)
-            if polygon is not None
-        ])
+        Return a new :class:`xarray.Dataset`
+        with all geometry variables dropped.
+        Useful when significantly transforming the dataset,
+        such as :mod:`extracting point data <emsarray.operations.point_extraction>`.
+        """
+        pass
 
     @abc.abstractmethod
     def make_clip_mask(
@@ -1201,15 +1190,15 @@ class Format(abc.ABC, Generic[GridKind, Index]):
     # Aliases for emsarray.operations
 
     def ocean_floor(self) -> xr.Dataset:
-        """An alias for :func:`.operations.ocean_floor`"""
-        return operations.ocean_floor(
+        """An alias for :func:`emsarray.operations.depth.ocean_floor`"""
+        return depth.ocean_floor(
             self.dataset, self.get_all_depth_names(),
             non_spatial_variables=[self.get_time_name()])
 
     def normalize_depth_variables(
         self, positive_down: bool = True, deep_to_shallow: bool = True,
     ) -> xr.Dataset:
-        """An alias for :func:`.operations.normalize_depth_variables`"""
-        return operations.normalize_depth_variables(
+        """An alias for :func:`emsarray.operations.depth.normalize_depth_variables`"""
+        return depth.normalize_depth_variables(
             self.dataset, self.get_all_depth_names(),
             positive_down=positive_down, deep_to_shallow=deep_to_shallow)
