@@ -25,6 +25,9 @@ from shapely.geometry import Polygon
 from shapely.geometry.base import BaseGeometry
 
 from emsarray import utils
+from emsarray.exceptions import (
+    ConventionViolationError, ConventionViolationWarning
+)
 from emsarray.types import Pathish
 
 from ._base import Format
@@ -132,12 +135,46 @@ def mask_from_face_indices(face_indices: np.ndarray, topology: Mesh2DTopology) -
     })
 
 
+def _get_start_index(connectivity: xr.DataArray) -> int:
+    """
+    Get the ``start_index`` attribute from a connectivity data array,
+    while checking for common error cases.
+    """
+    # Default to 0 if there is no start_index attribute
+    if 'start_index' not in connectivity.attrs:
+        return 0
+
+    start_index = connectivity.attrs.get('start_index')
+
+    # These are the valid values
+    if start_index in {0, 1}:
+        return cast(int, start_index)
+
+    # Some datasets use the strings '0' or '1'.
+    # This does not adhere to the spec but is easy to interpret
+    if start_index in {'0', '1'}:
+        warnings.warn(
+            f"Connectivity data array {connectivity.name!r} "
+            f"had string-typed start index {start_index!r}. "
+            f"This attribute should be the integer {int(start_index)}, "
+            f"not a string.",
+            ConventionViolationWarning,
+        )
+        return int(start_index)
+
+    # Anything else is incorrect
+    raise ConventionViolationError(
+        f"Connectivity data array {connectivity.name!r} "
+        f"had invalid start index {start_index!r}"
+    )
+
+
 def update_connectivity(
     connectivity: xr.DataArray,
     old_array: np.ndarray,
     row_indices: np.ndarray,
     column_values: np.ndarray,
-    primary_dimension: str,
+    primary_dimension: Hashable,
     fill_value: int,
 ) -> xr.DataArray:
     """
@@ -169,7 +206,7 @@ def update_connectivity(
         A one dimensional numpy masked array
         mapping values from ``old_array`` to their new values.
         Values to be excluded in the new array should be ``np.ma.masked``
-    primary_dimension : str
+    primary_dimension : Hashable
         The name of the primary dimension for this connectivity variable.
         This will be either :attr:`Mesh2DTopology.edge_dimension`
         or :attr:`Mesh2DTopology.face_dimension`.
@@ -186,7 +223,7 @@ def update_connectivity(
     logger.debug("Reindexing %r", connectivity.name)
 
     # Offset the column_values for one-based indexing.
-    start_index = connectivity.attrs.get('start_index', 0)
+    start_index = _get_start_index(connectivity)
     if start_index != 0:
         column_values = column_values + start_index
 
@@ -305,9 +342,9 @@ class Mesh2DTopology:
     dataset: xr.Dataset
 
     #: The name of the mesh topology variable. Optional. If not provided, the
-    #: mesh topology dummy variable will be found by checking the `cf_role`
+    #: mesh topology dummy variable will be found by checking the ``cf_role``
     #: attribute.
-    topology_key: Optional[str] = None
+    topology_key: Optional[Hashable] = None
 
     #: The default dtype to use for index data arrays. Hard coded to ``int32``,
     #: which should be sufficient for all datasets. ``int16`` is too small for
@@ -375,16 +412,16 @@ class Mesh2DTopology:
         return int('9' * (len(str(max_count)) + 1))
 
     @cached_property
-    def _node_coordinates(self) -> Tuple[str, str]:
-        return _split_coord(cast(str, self.mesh_attributes['node_coordinates']))
+    def _node_coordinates(self) -> Tuple[Hashable, Hashable]:
+        return _split_coord(self.mesh_attributes['node_coordinates'])
 
     @cached_property
-    def _edge_coordinates(self) -> Tuple[str, str]:
-        return _split_coord(cast(str, self.mesh_attributes['edge_coordinates']))
+    def _edge_coordinates(self) -> Tuple[Hashable, Hashable]:
+        return _split_coord(self.mesh_attributes['edge_coordinates'])
 
     @cached_property
-    def _face_coordinates(self) -> Tuple[str, str]:
-        return _split_coord(cast(str, self.mesh_attributes['face_coordinates']))
+    def _face_coordinates(self) -> Tuple[Hashable, Hashable]:
+        return _split_coord(self.mesh_attributes['face_coordinates'])
 
     @property
     def node_x(self) -> xr.DataArray:
@@ -431,7 +468,7 @@ class Mesh2DTopology:
     def _to_index_array(
         self,
         data_array: xr.DataArray,
-        primary_dimension: str,
+        primary_dimension: Hashable,
     ) -> np.ndarray:
         """
         Convert a data array of node, edge, or face indices
@@ -441,8 +478,9 @@ class Mesh2DTopology:
         """
         # Ensure the dimensions are in the correct order first
         if primary_dimension not in data_array.dims:
-            raise ValueError(
-                f"Data array did not contain primary dimension {primary_dimension!r}")
+            raise ConventionViolationError(
+                f"Data array {data_array.name!r} did not contain "
+                f"primary dimension {primary_dimension!r}")
         if data_array.dims[0] != primary_dimension:
             data_array = data_array.transpose()
 
@@ -466,7 +504,7 @@ class Mesh2DTopology:
 
         # UGRID conventions allow for zero based or one based indexing.
         # To be consistent we convert all indices to zero based.
-        start_index = data_array.attrs.get('start_index', 0)
+        start_index = _get_start_index(data_array)
         if start_index != 0:
             values = values - start_index
 
@@ -493,7 +531,8 @@ class Mesh2DTopology:
         if actual != expected:
             warnings.warn(
                 f"Got a edge_node_connectivity variable {data_array.name!r} with "
-                f"unexpected dimensions {actual}, expecting {expected}"
+                f"unexpected dimensions {actual}, expecting {expected}",
+                ConventionViolationWarning,
             )
             return False
 
@@ -581,7 +620,8 @@ class Mesh2DTopology:
         if actual != expected:
             warnings.warn(
                 f"Got a face_face_connectivity variable {data_array.name!r} with "
-                f"unexpected dimensions {actual}, expecting {expected}"
+                f"unexpected dimensions {actual}, expecting {expected}",
+                ConventionViolationWarning,
             )
             return False
 
@@ -648,7 +688,8 @@ class Mesh2DTopology:
         if actual != expected:
             warnings.warn(
                 f"Got a face_face_connectivity variable {data_array.name!r} with "
-                f"unexpected dimensions {actual}, expecting {expected}"
+                f"unexpected dimensions {actual}, expecting {expected}",
+                ConventionViolationWarning,
             )
             return False
 
@@ -692,7 +733,8 @@ class Mesh2DTopology:
         if actual != expected:
             warnings.warn(
                 f"Got a face_edge_connectivity variable {data_array.name!r} with "
-                f"unexpected dimensions {actual}, expecting {expected}"
+                f"unexpected dimensions {actual}, expecting {expected}",
+                ConventionViolationWarning,
             )
             return False
 
@@ -762,7 +804,8 @@ class Mesh2DTopology:
         if actual != expected:
             warnings.warn(
                 f"Got a face_face_connectivity variable {data_array.name!r} with "
-                f"unexpected dimensions {actual}, expecting {expected}"
+                f"unexpected dimensions {actual}, expecting {expected}",
+                ConventionViolationWarning,
             )
             return False
 
@@ -827,7 +870,7 @@ class Mesh2DTopology:
             yield face_index, list(utils.pairwise(node_indices))
 
     @cached_property
-    def dimension_for_grid_kind(self) -> Dict[UGridKind, str]:
+    def dimension_for_grid_kind(self) -> Dict[UGridKind, Hashable]:
         """
         Get the dimension names for each of the grid types in this dataset.
         """
@@ -836,11 +879,11 @@ class Mesh2DTopology:
             UGridKind.node: self.node_dimension,
         }
         if self.has_edge_dimension:
-            dimensions[UGridKind.edge] = cast(str, self.edge_dimension)
+            dimensions[UGridKind.edge] = self.edge_dimension
         return dimensions
 
     @cached_property
-    def two_dimension(self) -> str:
+    def two_dimension(self) -> Hashable:
         """
         Get the name of the dimension with size two, for things like edge
         connectivity. The standard name for this dimension is 'Two'.
@@ -852,16 +895,16 @@ class Mesh2DTopology:
         # Check for any other dimension of size 2
         for name, size in self.dataset.dims.items():
             if size == 2:
-                return str(name)
+                return name
         # Make up a new dimension with the standard name
         return two
 
     @property
-    def node_dimension(self) -> str:
+    def node_dimension(self) -> Hashable:
         """The name of the dimension for the number of nodes."""
         # This is implicitly given by some of the required variables, such as
         # the variable for node x-coordinates.
-        return str(self.node_x.dims[0])
+        return self.node_x.dims[0]
 
     @property
     def has_edge_dimension(self) -> bool:
@@ -884,7 +927,7 @@ class Mesh2DTopology:
         )
 
     @cached_property
-    def edge_dimension(self) -> str:
+    def edge_dimension(self) -> Hashable:
         """
         The name of the dimension for the number of edges.
         """
@@ -904,30 +947,30 @@ class Mesh2DTopology:
         variables = (self.dataset.variables[name] for name in names if name in self.dataset.variables)
 
         try:
-            return next(str(variable.dims[0]) for variable in variables)
+            return next(variable.dims[0] for variable in variables)
         except StopIteration:
             # This should have already happened above, but just in case.
             raise NoEdgeDimensionException
 
     @cached_property
-    def face_dimension(self) -> str:
+    def face_dimension(self) -> Hashable:
         """The name of the dimension for the number of faces."""
         try:
             # By definition this is either the dimension named in this attribute ...
             return self.mesh_attributes['face_dimension']
         except KeyError:
             # ... Or the first dimension in this required variable
-            return str(self.face_node_connectivity.dims[0])
+            return self.face_node_connectivity.dims[0]
 
     @property
-    def max_node_dimension(self) -> str:
+    def max_node_dimension(self) -> Hashable:
         """The name of the dimension for the maximum nodes / edges per face."""
         # This dimension is not named as part of the UGRID spec, but it is
         # always the other dimension in the `face_node_connectivity` variable.
         dims = set(self.face_node_connectivity.dims)
         assert len(dims) == 2
         dims.remove(self.face_dimension)
-        return str(dims.pop())
+        return dims.pop()
 
     @property
     def node_count(self) -> int:
@@ -1061,7 +1104,7 @@ class UGrid(Format[UGridKind, UGridIndex]):
             return cast(np.ndarray, face_centres)
         return super().face_centres
 
-    def selector_for_index(self, index: UGridIndex) -> Dict[str, int]:
+    def selector_for_index(self, index: UGridIndex) -> Dict[Hashable, int]:
         kind, i = index
         if kind is UGridKind.face:
             return {self.topology.face_dimension: i}
@@ -1248,3 +1291,35 @@ class UGrid(Format[UGridKind, UGridIndex]):
         logger.debug("Merging individual variables...")
         new_dataset = xr.open_mfdataset(mfdataset_paths, lock=False)
         return utils.dataset_like(dataset, new_dataset)
+
+    def drop_geometry(self) -> xr.Dataset:
+        dataset = self.dataset
+        topology = self.topology
+
+        geometry_variables = [
+            topology.mesh_variable.name,
+            topology.face_node_connectivity.name,
+            topology.node_x.name,
+            topology.node_y.name,
+        ]
+        if topology.has_valid_face_edge_connectivity:
+            geometry_variables.append(topology.face_edge_connectivity.name)
+        if topology.has_valid_face_face_connectivity:
+            geometry_variables.append(topology.face_face_connectivity.name)
+        if topology.has_valid_edge_node_connectivity:
+            geometry_variables.append(topology.edge_node_connectivity.name)
+        if topology.has_valid_edge_face_connectivity:
+            geometry_variables.append(topology.edge_face_connectivity.name)
+        if topology.edge_x is not None:
+            geometry_variables.append(topology.edge_x)
+        if topology.edge_y is not None:
+            geometry_variables.append(topology.edge_y)
+        if topology.face_x is not None:
+            geometry_variables.append(topology.face_x)
+        if topology.face_y is not None:
+            geometry_variables.append(topology.face_y)
+
+        dataset = dataset.drop_vars(geometry_variables)
+        dataset.attrs.pop('Conventions', None)
+
+        return dataset
